summaryrefslogtreecommitdiffstats
path: root/services/audioflinger/Threads.h
diff options
context:
space:
mode:
authorAndy Hung <hunga@google.com>2014-02-27 14:00:06 -0800
committerAndy Hung <hunga@google.com>2014-02-27 14:22:08 -0800
commit2098f2744cedf2dc3fa36f608aa965a34602e7c0 (patch)
tree901ba9039b8baa3b33c82871e32430decceaac38 /services/audioflinger/Threads.h
parent4d3c5bde85c5404d7927a770da90a5c9d09fb6a7 (diff)
downloadframeworks_av-2098f2744cedf2dc3fa36f608aa965a34602e7c0.zip
frameworks_av-2098f2744cedf2dc3fa36f608aa965a34602e7c0.tar.gz
frameworks_av-2098f2744cedf2dc3fa36f608aa965a34602e7c0.tar.bz2
Rename mMixBuffer to mSinkBuffer in AudioFlinger
Change-Id: I1f55630425b8ce36e9df2aaf64e06a8960b69a47 Signed-off-by: Andy Hung <hunga@google.com>
Diffstat (limited to 'services/audioflinger/Threads.h')
-rw-r--r--services/audioflinger/Threads.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/services/audioflinger/Threads.h b/services/audioflinger/Threads.h
index fa3563c..5efa746 100644
--- a/services/audioflinger/Threads.h
+++ b/services/audioflinger/Threads.h
@@ -450,7 +450,8 @@ public:
virtual String8 getParameters(const String8& keys);
virtual void audioConfigChanged_l(int event, int param = 0);
status_t getRenderPosition(uint32_t *halFrames, uint32_t *dspFrames);
- int16_t *mixBuffer() const { return mMixBuffer; };
+ // TODO: rename mixBuffer() to sinkBuffer() or try to remove external use.
+ int16_t *mixBuffer() const { return mSinkBuffer; };
virtual void detachAuxEffect_l(int effectId);
status_t attachAuxEffect(const sp<AudioFlinger::PlaybackThread::Track> track,
@@ -481,7 +482,7 @@ protected:
// updated by readOutputParameters_l()
size_t mNormalFrameCount; // normal mixer and effects
- int16_t* mMixBuffer; // frame size aligned mix buffer
+ int16_t* mSinkBuffer; // frame size aligned sink buffer
// suspend count, > 0 means suspended. While suspended, the thread continues to pull from
// tracks and mix, but doesn't write to HAL. A2DP and SCO HAL implementations can't handle